import { Button, IconButton } from '@suid/material';
import { Component, createSignal } from 'solid-js';
import WptIcon from '../../icons/location-pin-svgrepo-com.svg?component-solid';
import { peekCachedSignal } from '../../workers/cached-signals';
import dispatch from '../../workers/dispatcher-main';
import { useI18n } from '@solid-primitives/i18n';
import Tree from '../tree';
import WptEditButtonAndDialog from './WptEditButtonAndDialog';
import DeleteIcon from '@suid/icons-material/Delete';
import QuestionMarkIcon from '@suid/icons-material/QuestionMark';
import Alert from '../alert';

interface Props {
  wptId: string;
}

const WptViewer: Component<Props> = ({ wptId }) => {
  const [t, { add, locale, dict }] = useI18n();
  const wpt = peekCachedSignal({ id: wptId, method: 'getWpt' });
  console.log({ caller: 'WptViewer', wptId, wpt: wpt() });
  const title = () => {
    return wpt().name;
  };

  const [confirmDelete, setConfirmDelete] = createSignal(false);

  const confirmDeleteHandler = () => {
    console.log({
      caller: 'WptViewer / confirmDeleteHandler',
      wptId,
    });
    setConfirmDelete(true);
  };

  const deleteHandler = () => {
    console.log({
      caller: 'WptViewer / deleteHandler',
      wptId,
    });
    dispatch({ action: 'deleteWpt', params: { id: wptId } });
    setConfirmDelete(false);
  };

  const cancelDeleteHandler = () => {
    console.log({
      caller: 'WptViewer / cancelDeleteHandler',
      wptId,
    });
    setConfirmDelete(false);
  };

  return (
    <>
      <Tree
        title={
          <>
            <WptIcon
              fill='black'
              width='24'
              height='24'
              viewBox='0 0 300 300'
            />
            {title()}
            <WptEditButtonAndDialog wptId={wptId} />
            <div>
              <IconButton onClick={confirmDeleteHandler}>
                <DeleteIcon fill='white' />
              </IconButton>
            </div>
          </>
        }
        content={undefined}
        subTree={undefined}
      />
      <Alert
        open={confirmDelete}
        closeHandler={cancelDeleteHandler}
        severity='warning'
        icon={<QuestionMarkIcon />}
        action={
          <>
            <Button
              color='error'
              variant='contained'
              size='small'
              onClick={deleteHandler}
            >
              {t('yes')}
            </Button>
            <Button
              color='primary'
              variant='outlined'
              size='small'
              onclick={cancelDeleteHandler}
            >
              {t('no')}
            </Button>
          </>
        }
      >
        {t('deleteTrack')}
      </Alert>
    </>
  );
};

export default WptViewer;
