import { createSignal, Signal } from 'solid-js';

declare global {
  var exportQueue: Map<string, any>;
}

let worker: Worker;

const init = () => {
  console.log({ caller: 'solid-worker-main / init' });
  globalThis.exportQueue = new Map<
    string,
    { count: number; signal: Signal<any> }
  >();

  worker = new Worker(new URL('./solid-worker', import.meta.url), {
    type: 'module',
  });

  worker.onmessage = (event: any) => {
    const { _id, _updatedValue } = event.data;
    console.log({
      caller: 'solid-worker-main / message received',
      _id,
      _updatedValue,
    });
    if (!globalThis.exportQueue.get(_id)) {
      console.error({
        caller: 'solid-worker-main / message received',
        message: 'not found',
        _id,
        _updatedValue,
      });
    }
    const signal = globalThis.exportQueue.get(_id).signal;
    signal[1](_updatedValue);
  };
};

export const createWorkerSignal = (parameters: {
  provider: string;
  params?: any;
  initialValue?: any;
}) => {
  if (!worker) {
    init();
  }
  const { provider, params, initialValue } = parameters;
  const id = JSON.stringify({ provider, params });
  if (globalThis.exportQueue.has(id)) {
    globalThis.exportQueue.get(id).count++;
    console.log({
      caller: 'solid-worker / createWorkerSignal / existing',
      queueItem: globalThis.exportQueue.get(id),
    });
    return globalThis.exportQueue.get(id).signal;
  }
  const signal = createSignal(initialValue);
  globalThis.exportQueue.set(id, { signal, count: 1 });
  worker.postMessage({ ...parameters, _id: id });
  console.log({
    caller: 'solid-worker / createWorkerSignal / new',
    queueItem: globalThis.exportQueue.get(id),
  });
  return signal;
};

export const releaseWorkerSignal = (parameters: {
  provider: string;
  params: any;
}) => {
  const { provider, params } = parameters;
  const id = JSON.stringify({ provider, params });
  if (globalThis.exportQueue.has(id)) {
    globalThis.exportQueue.get(id).count--;
    if (globalThis.exportQueue.get(id).count === 0) {
      globalThis.exportQueue.delete(id);
      worker.postMessage({ ...parameters, _id: id, _release: true });
    }
  }
};
