import { until } from '../lib/async-wait';
import { getWorker } from './get-worker';

declare global {
  var dispatcherQueue: { index: number; queue: Map<number, any> };
  var dbReady: boolean;
  var worker: any;
}

export const init = () => {
  //  console.log({ caller: 'dispatcher-main / init' });
  globalThis.dispatcherQueue = { index: 0, queue: new Map() };
  // console.log({ caller: 'dispatcher-main / init', globalThis });

  globalThis.worker = getWorker();
  // console.log({ caller: 'dispatcher-main / init', worker });

  globalThis.worker.onmessage = (event: any) => {
    const { id, payload } = event.data;
    // console.log({
    //   caller: 'dispatcher-main / message received',
    //   id,
    //   payload,
    //   dispatcherQueue: JSON.parse(JSON.stringify(dispatcherQueue)),
    // });
    globalThis.dispatcherQueue.queue.get(id).callBack(null, payload, id);
    if (!globalThis.dispatcherQueue.queue.get(id).live) {
      cancelDispatch(id);
    }
  };
};

const dispatch = async (
  payload: any,
  callBack?: (error: any, result: any, id?: number | undefined) => void,
  live?: boolean
) => {
  let initializing = false;
  console.log({
    caller: 'dispatcher-main / dispatch',
    payload,
    callBack,
    initializing,
    worker: globalThis.worker,
  });
  if (globalThis.worker === undefined && !initializing) {
    initializing = true;
    init();
    await until(() => !!globalThis.worker, 100); // wait until the worker is initialized
    dispatch({ action: 'initDb' }, (error, result) => {
      if (error) {
        console.error({ caller: 'worker-main / init', error });
        return;
      }
      globalThis.dbReady = true;
    });
    initializing = false;
  }
  if (payload.action !== 'initDb') {
    await until(() => globalThis.dbReady, 100); // Wait until databases have been initialized
  }
  if (callBack === undefined) {
    /** If a callback function is not provided, return a promise */
    return new Promise((resolve, reject) => {
      dispatch(payload, (error, result) => {
        if (error) {
          reject(error);
        } else {
          resolve(result);
        }
      });
    });
  }
  /** Otherwise, use the callback function */
  globalThis.dispatcherQueue.queue.set(globalThis.dispatcherQueue.index, {
    callBack,
    live,
  });
  const message = {
    id: globalThis.dispatcherQueue.index++,
    payload: payload,
  };
  worker.postMessage(message);
  console.log({
    caller: 'dispatcher-main / message sent',
    message,
    dispatcherQueue: globalThis.dispatcherQueue,
  });
};

export const cancelDispatch = (id: number) => {
  globalThis.dispatcherQueue.queue.delete(id);
};

export default dispatch;
